"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndexOutOfBoundsError = void 0;
const AdapterError_cjs_1 = require("./AdapterError.cjs");
/**
 * Represents an error indicating that the requested index is out of bounds.
 */
class IndexOutOfBoundsError extends AdapterError_cjs_1.AdapterError {
    /**
     * Initializes a new instance of the {@linkcode IndexOutOfBoundsError} class.
     *
     * @param adapter
     * The adapter which caused the error.
     *
     * @param indexNode
     * The node containing the invalid index.
     *
     * @param segmentCount
     * The number of available segments.
     *
     * @param context
     * The context of the operation.
     */
    constructor(adapter, indexNode, segmentCount, context) {
        super(adapter, indexNode.Source, context);
        this.indexNode = indexNode;
        this.segmentCount = Math.abs(segmentCount);
    }
    /**
     * Gets the node containing the invalid index.
     */
    get IndexNode() {
        return this.indexNode;
    }
    /**
     * Gets the invalid index.
     */
    get Index() {
        return this.IndexNode.Value;
    }
    /**
     * Gets the number of available segments.
     */
    get SegmentCount() {
        return this.segmentCount;
    }
    /**
     * @inheritdoc
     */
    get Message() {
        let expectation;
        if (this.SegmentCount === 0) {
            expectation = "0";
        }
        else {
            expectation = `a value between ${-this.SegmentCount} and ${this.SegmentCount - 1}`;
        }
        return `The specified index is invalid. Expected ${expectation}, but got ${this.Index}`;
    }
}
exports.IndexOutOfBoundsError = IndexOutOfBoundsError;
//# sourceMappingURL=IndexOutOfBoundsError.cjs.map