"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InvalidArgumentCountError = void 0;
const NameofCallError_cjs_1 = require("./NameofCallError.cjs");
/**
 * Represents an error indicating an invalid `interpolate` call.
 */
class InvalidArgumentCountError extends NameofCallError_cjs_1.NameofCallError {
    /**
     * Initializes a new instance of the {@linkcode NoSingleArgumentError} class.
     *
     * @param adapter
     * The adapter which caused the error.
     *
     * @param call
     * The `nameof` call which caused the error.
     *
     * @param expected
     * The expected number of arguments.
     *
     * @param context
     * The context of the operation.
     */
    constructor(adapter, call, expected, context) {
        super(adapter, call, context);
        this.expected = expected;
    }
    /**
     * Gets the expected number of arguments.
     */
    get Expected() {
        return this.expected;
    }
    /**
     * @inheritdoc
     */
    get Message() {
        return `Expected ${this.Expected} argument for the \`${this.FunctionName}\` call, but got ${this.Call.arguments.length}.`;
    }
}
exports.InvalidArgumentCountError = InvalidArgumentCountError;
//# sourceMappingURL=InvalidArgumentCountError.cjs.map