"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NameofCallError = void 0;
const AdapterError_cjs_1 = require("./AdapterError.cjs");
/**
 * Represents an error which is related to a {@linkcode NameofCall}.
 */
class NameofCallError extends AdapterError_cjs_1.AdapterError {
    /**
     * Initializes a new instance of the {@linkcode NameofCallError}.
     *
     * @param adapter
     * The adapter which caused the error.
     *
     * @param call
     * The function call related to the error.
     *
     * @param context
     * The context of the operation.
     */
    constructor(adapter, call, context) {
        super(adapter, call.source, context);
        this.call = call;
    }
    /**
     * Gets the function call related to the error.
     */
    get Call() {
        return this.call;
    }
    /**
     * Gets the full name of the function which has been called.
     */
    get FunctionName() {
        let result = this.NameofName;
        if (this.Call.function) {
            result += `.${this.Call.function}`;
        }
        return result;
    }
    /**
     * Gets the arguments of the function call.
     */
    get Arguments() {
        return this.Call.arguments;
    }
    /**
     * Gets the type arguments of the function call.
     */
    get TypeArguments() {
        return this.Call.typeArguments;
    }
    /**
     * Gets a text indicating the number of arguments.
     */
    get ArgumentCountText() {
        let count = this.Arguments.length;
        return `${count} argument${this.GetPluralSuffix(count)}`;
    }
    /**
     * Gets a text indicating the number of type arguments.
     */
    get TypeArgumentCountText() {
        let count = this.TypeArguments.length;
        return `${count} type argument${this.GetPluralSuffix(count)}`;
    }
    /**
     * Gets the proper plural suffix for the specified {@linkcode amount} of entities.
     *
     * @param amount
     * The number of entities to get the plural suffix for.
     *
     * @returns
     * The proper suffix for the specified {@linkcode amount}.
     */
    GetPluralSuffix(amount) {
        if (amount === 1) {
            return "";
        }
        else {
            return "s";
        }
    }
}
exports.NameofCallError = NameofCallError;
//# sourceMappingURL=NameofCallError.cjs.map