import { Node } from "./Node.cjs";
/**
 * Represents a call expression node.
 */
export declare abstract class CallNodeBase<T> extends Node<T> {
    /**
     * The type arguments of the call.
     */
    private typeArguments;
    /**
     * The arguments of the call.
     */
    private arguments;
    /**
     * Initializes a new instance of the {@linkcode CallNodeBase} class.
     *
     * @param source
     * The source of the node.
     *
     * @param typeArguments
     * The type arguments of the call.
     *
     * @param args
     * The arguments of the call.
     */
    constructor(source: T, typeArguments: readonly T[], args: readonly T[]);
    /**
     * Gets the type arguments of the call.
     */
    get TypeArguments(): readonly T[];
    /**
     * Gets the arguments of the call.
     */
    get Arguments(): readonly T[];
}
