"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndexAccessNode = void 0;
const AccessExpressionNode_cjs_1 = require("./AccessExpressionNode.cjs");
/**
 * Represents an index access node.
 */
class IndexAccessNode extends AccessExpressionNode_cjs_1.AccessExpressionNode {
    /**
     * Initializes a new instance of the {@linkcode IndexAccessNode} class.
     *
     * @param source
     * The source of the node.
     *
     * @param expression
     * The expression of the index access operation.
     *
     * @param property
     * The property to access.
     */
    constructor(source, expression, property) {
        super(source, expression, property);
        /**
         * @inheritdoc
         */
        this.Type = "IndexAccessNode" /* NodeKind.IndexAccessNode */;
    }
    /**
     * @inheritdoc
     */
    get PathPart() {
        let source = this.Property.Source;
        switch (this.Property.Type) {
            case "NumericLiteralNode" /* NodeKind.NumericLiteralNode */:
            case "StringLiteralNode" /* NodeKind.StringLiteralNode */:
                let value;
                if (this.Property.Type === "NumericLiteralNode" /* NodeKind.NumericLiteralNode */) {
                    value = this.Property.Value;
                }
                else {
                    value = this.Property.Text;
                }
                return {
                    type: "IndexAccess" /* PathKind.IndexAccess */,
                    source,
                    value
                };
            case "InterpolationNode" /* NodeKind.InterpolationNode */:
                return this.Property.PathPart;
            default:
                return {
                    type: "Unsupported" /* PathKind.Unsupported */,
                    isAccessor: true,
                    source
                };
        }
    }
}
exports.IndexAccessNode = IndexAccessNode;
//# sourceMappingURL=IndexAccessNode.cjs.map