"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransformerFeatures = void 0;
const ErrorHandler_cjs_1 = require("./ErrorHandler.cjs");
/**
 * Provides features for performing `nameof` transformations.
 */
class TransformerFeatures {
    /**
     * Initializes a new instance of the {@linkcode TransformerFeatures TransformerFeatures<T>} class.
     *
     * @param errorHandler
     * A component for reporting errors.
     */
    constructor(errorHandler) {
        this.errorHandler = errorHandler;
    }
    /**
     * Gets a component for reporting errors.
     */
    get ErrorHandler() {
        if (!this.errorHandler) {
            this.errorHandler = this.InitializeErrorHandler();
        }
        return this.errorHandler;
    }
    /**
     * Reports the specified {@linkcode error}.
     *
     * @param location
     * The location of the specified {@linkcode node}.
     *
     * @param item
     * The item the specified {@linkcode error} is related to.
     *
     * @param context
     * The context of the operation.
     *
     * @param error
     * The error to report.
     */
    ReportError(location, item, context, error) {
        var _a;
        (_a = this.ErrorHandler) === null || _a === void 0 ? void 0 : _a.Report(location, item, context, error);
    }
    /**
     * Initializes a new error handler.
     *
     * @returns
     * The newly created error handler.
     */
    InitializeErrorHandler() {
        return new ErrorHandler_cjs_1.ErrorHandler();
    }
}
exports.TransformerFeatures = TransformerFeatures;
//# sourceMappingURL=TransformerFeatures.cjs.map